@@ -140,9 +140,11 @@ impl BenchRunMetricsItem {
                 truncated_mean
             );
             truncated_mean
-        } else {
+        } else if ignored_count > 0 {
             error!("No data points");
             0
+        } else {
+            0
         }
     }
 }
@@ -513,7 +515,7 @@ mod tests {
     fn test_has_more_work_request_limit() {
         let requests = 10;
         let mut metrics =
-            BenchRun::from_request_limit(0, requests, RateLimiter::build_rate_limiter(0.));
+            BenchRun::from_request_limit(0, requests, RateLimiter::build_rate_limiter(0.), None);
         for _ in 0..requests {
             assert!(metrics.has_more_work());
         }
@@ -524,7 +526,7 @@ mod tests {
     fn test_has_more_work_time_limit() {
         let duration = Duration::from_secs(1);
         let mut metrics =
-            BenchRun::from_duration_limit(0, duration, RateLimiter::build_rate_limiter(0.));
+            BenchRun::from_duration_limit(0, duration, RateLimiter::build_rate_limiter(0.), None);
         for _ in 0..1000 {
             assert!(metrics.has_more_work());
         }
